<% if pollable? %>
    <a class="live-poll-start live-poll btn btn-primary"><%= t('LivePoll') %></a>
    <a class="live-poll-stop live-poll btn btn-primary active"><%= t('StopPolling') %></a>
<% end %>
